<div align="right"><img src="https://travis-ci.org/ozmartian/vidcutter.svg?branch=master" /></div>

![VidCutter](https://raw.githubusercontent.com/ozmartian/vidcutter/master/images/vidcutter.png)

<p><b>Homepage:</b> <a href="http://vidcutter.ozmartians.com" target=_blank">http://vidcutter.ozmartians.com</a></p>

Cross-platform Qt5 based app for quick and easy video trimming/splitting and merging/joining for simple quick edits.
FFmpeg dives the backend with a stylishly hand edited Qt5 UI. FFmpg static binary is pre-installed for Windows builds.
For non-windows, use your o/s package manager if on Linux and homebrew for Mac OS X to manage FFmpeg. It is most likely already installed on your Linux or macOS machine.
